unit FormDatenEinlesen;
{$DEFINE USESQLDBGUI}
interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls,
  SQLDB, DB
  {$ifdef USESQLDBGUI} , udmsqldb {$else} ,usqldbruntime {$endif}
  ;

type
  { TFormDatenEinlesen }
  TFormDatenEinlesen = class(TForm)
    btnTXT: TButton;
    btnAbb: TButton;
    btnOK: TButton;
    Button1: TButton;
    EditName: TEdit;
    MemoDaten: TMemo;
    MemoComment: TMemo;
    procedure btnAbbClick(Sender: TObject);
    procedure btnOKClick(Sender: TObject);
    procedure btnTXTClick(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  public
    ExternalSQLQuery: TSQLQuery;
    procedure InitializeDB;
  end;

var
  frmDatenEinlesen: TFormDatenEinlesen;

implementation

{$R *.lfm}

procedure TFormDatenEinlesen.FormCreate(Sender: TObject);
begin
  ExternalSQLQuery := TSQLQuery.Create(Self);
  ExternalSQLQuery.DataBase := dmsqldb.SQLConnector1;
  dmsqldb.OpenConnection;
  InitializeDB;
end;

procedure TFormDatenEinlesen.InitializeDB;
begin
  with dmsqldb.SQLConnector1 do
  begin
    ExecuteDirect('CREATE TABLE IF NOT EXISTS DataSet (' +
                  'ID INTEGER PRIMARY KEY AUTOINCREMENT, ' +
                  'CreationDate TEXT, ' +
                  'Name TEXT, ' +
                  'Comment TEXT)');

    ExecuteDirect('CREATE TABLE IF NOT EXISTS UnsortedValues (' +
                  'DataSetID INTEGER, ' +
                  'Value TEXT, ' +
                  'FOREIGN KEY (DataSetID) REFERENCES DataSet(ID))');

    ExecuteDirect('CREATE TABLE IF NOT EXISTS Measurements (' +
                  'ID INTEGER PRIMARY KEY AUTOINCREMENT, ' +
                  'DataSetID INTEGER, ' +
                  'MeasurementDate TEXT, ' +
                  'AlgorithmName TEXT, ' +
                  'M1 REAL, M2 REAL, M3 REAL, M4 REAL, M5 REAL, ' +
                  'FOREIGN KEY (DataSetID) REFERENCES DataSet(ID))');
  end;
end;

procedure TFormDatenEinlesen.btnTXTClick(Sender: TObject);
var
  FileContent: TStringList;
  Delimiters: array of Char;
  Info: String;
  OpenDialog: TOpenDialog;
begin

  OpenDialog := TOpenDialog.Create(Self);  // Stellen Sie sicher, dass der Dialog existiert

  if OpenDialog.Execute then
  begin
    FileContent := TStringList.Create;
    try
      FileContent.LoadFromFile(OpenDialog.FileName);
      if Pos(',', FileContent.Text) > 0 then
        Delimiters := [',']
      else if Pos(';', FileContent.Text) > 0 then
        Delimiters := [';']
      else if Pos(#9, FileContent.Text) > 0 then
        Delimiters := [#9]
      else
        Delimiters := [#13, #10]; // Zeilenumbrüche als Trennzeichen

      Info := Format('Dateiname: %s, Zeichenanzahl: %d, Datenanzahl: %d',
        [OpenDialog.FileName, Length(FileContent.Text), Length(FileContent.Text.Split(Delimiters))]);
      ShowMessage(Info);
      MemoDaten.Lines.Assign(FileContent);
    finally
      FileContent.Free;
    end;
  end;
 end;



procedure TFormDatenEinlesen.Button1Click(Sender: TObject);
          begin
 if Assigned(ExternalSQLQuery) and Assigned(ExternalSQLQuery.DataBase) and ExternalSQLQuery.DataBase.Connected then
 begin
   // Ihr bestehender Code hier
 end
 else
   ShowMessage('Datenbankverbindung ist nicht verfügbar.');
end;


procedure TFormDatenEinlesen.btnOKClick(Sender: TObject);
var
  DataSetID: Integer;
  Value: String;
begin
  try
    ExternalSQLQuery.Close;
    ExternalSQLQuery.SQL.Text := 'INSERT INTO DataSet (CreationDate, Name, Comment) VALUES (:CreationDate, :Name, :Comment)';
    ExternalSQLQuery.ParamByName('CreationDate').AsString := FormatDateTime('yyyy-mm-dd', Now);
    ExternalSQLQuery.ParamByName('Name').AsString := EditName.Text;
    ExternalSQLQuery.ParamByName('Comment').AsString := MemoComment.Text;
    ExternalSQLQuery.ExecSQL;

    ExternalSQLQuery.SQL.Text := 'SELECT last_insert_rowid() AS LastID';
    ExternalSQLQuery.Open;
    DataSetID := ExternalSQLQuery.Fields[0].AsInteger;
    ExternalSQLQuery.Close;

    for Value in MemoDaten.Lines do
    begin
      ExternalSQLQuery.SQL.Text := 'INSERT INTO UnsortedValues (DataSetID, Value) VALUES (:DataSetID, :Value)';
      ExternalSQLQuery.ParamByName('DataSetID').AsInteger := DataSetID;
      ExternalSQLQuery.ParamByName('Value').AsString := Value;
      ExternalSQLQuery.ExecSQL;
    end;

    ModalResult := mrOk;
  except
    on E: Exception do
    begin
      ShowMessage('Fehler bei der Datenverarbeitung: ' + E.Message);
    end;
  end;
end;








procedure TFormDatenEinlesen.btnAbbClick(Sender: TObject);
begin
  ModalResult := mrCancel; // Stellen Sie sicher, dass das Formular korrekt geschlossen wird
end;

end.
